@@ -1,5 +1,5 @@
 # -*- encoding: utf-8 -*-
-# kb v0.1.3
+# kb v0.1.4
 # A knowledge base organizer
 # Copyright © 2020, gnc.
 # See /LICENSE for licensing information.
@@ -26,6 +26,7 @@ import kb.initializer as initializer
 import kb.opener as opener
 import kb.viewer as viewer
 from kb.config import get_markers
+from kb.entities.artifact import Artifact
 
 
 def view(args: Dict[str, str], config: Dict[str, str]):
@@ -43,11 +44,11 @@ def view(args: Dict[str, str], config: Dict[str, str]):
                         hence the original will not be affected
     config:         - a configuration dictionary containing at least
                       the following keys:
-                      PATH_KB_DB        - the database path of KB
-                      PATH_KB_DATA      - the data directory of KB
-                      PATH_KB_HIST      - the history menu path of KB
-                      PATH_KB_MARKERS   - the file associated to the markers
-                      EDITOR            - the editor program to call
+                      PATH_KB_DB                 - the database path of KB
+                      PATH_KB_DATA               - the data directory of KB
+                      PATH_KB_HIST               - the history menu path of KB
+                      PATH_KB_DEFAULT_TEMPLATE   - the file associated to the markers
+                      EDITOR                     - the editor program to call
     """
     # Check initialization
     initializer.init(config)
@@ -110,7 +111,7 @@ def view_by_id(id: int,
 
     # View File
     if fs.is_text_file(artifact_path):
-        markers = get_markers(config["PATH_KB_MARKERS"])
+        markers = get_template(artifact, config)
         viewer.view(artifact_path, markers, color=color_mode)
     else:
         opener.open_non_text_file(artifact_path)
@@ -159,7 +160,7 @@ def view_by_name(title: str,
 
         # View File
         if fs.is_text_file(artifact_path):
-            markers = get_markers(config["PATH_KB_MARKERS"])
+            markers = get_template(artifact, config)
             viewer.view(artifact_path, markers, color=color_mode)
         else:
             opener.open_non_text_file(artifact_path)
@@ -169,3 +170,26 @@ def view_by_name(title: str,
     else:
         print(
             "There is no artifact with that name, please specify a correct artifact name")
+
+
+def get_template(artifact: Artifact, config: Dict[str, str]) -> str:
+    """"
+    Get template for a specific artifact.
+
+    Arguments:
+    artifact        - the artifact to get the template for
+    config:         - a configuration dictionary containing at least
+                      the following keys:
+                      PATH_KB_DEFAULT_TEMPLATE   - the file associated to the markers
+                      PATH_KB_TEMPLATES          - the path where templates are stored
+
+    Returns:
+    A dictionary containing markers, where the key is a regex
+    and the value is a string representing a color.
+    """
+    template = artifact.template or "default"
+    if template == "default":
+        markers = get_markers(config["PATH_KB_DEFAULT_TEMPLATE"])
+    else:
+        markers = get_markers(str(Path(*[config["PATH_KB_TEMPLATES"]] + template.split('/'))))
+    return markers
