@@ -1,5 +1,5 @@
 # -*- encoding: utf-8 -*-
-# kb v0.1.3
+# kb v0.1.4
 # A knowledge base organizer
 # Copyright © 2020, gnc.
 # See /LICENSE for licensing information.
@@ -88,14 +88,17 @@ def generate_search_header_verbose(
         [len(art.author) if art.author else 0 for art in search_result]), sec_min_length)
     len_status = max(max(
         [len(art.status) if art.status else 0 for art in search_result]), sec_min_length)
+    len_template = max(max(
+        [len(art.template) if art.template else 0 for art in search_result]), sec_min_length)
 
-    header = "   [ {id} ]  {title} {category} {tags} {author} {status}".format(
+    header = "   [ {id} ]  {title} {category} {tags} {author} {status} {template}".format(
         id="ID".rjust(len_id),
         title="Title".ljust(len_title),
         category="Category".ljust(len_categ),
         tags="Tags".ljust(len_tags),
         author="Author".ljust(len_author),
-        status="Status".ljust(len_status))
+        status="Status".ljust(len_status),
+        template="Template".ljust(len_template))
 
     if color:
         return UND + BOLD + header + RESET
@@ -178,20 +181,24 @@ def print_search_result_verbose(
         [len(art.author) if art.author else 0 for art in search_result]), sec_min_length)
     len_status = max(max(
         [len(art.status) if art.status else 0 for art in search_result]), sec_min_length)
+    len_template = max(max(
+        [len(art.template) if art.template else 0 for art in search_result]), sec_min_length)
 
     # Print results
     for view_id, artifact in enumerate(search_result):
         tags = artifact.tags if artifact.tags else ""
         author = artifact.author if artifact.author else ""
         status = artifact.status if artifact.status else ""
+        template = artifact.template if artifact.template else ""
 
-        result_line = "   [ {id} ]  {title} {category} {tags} {author} {status}".format(
+        result_line = "   [ {id} ]  {title} {category} {tags} {author} {status} {template}".format(
             id=str(view_id).rjust(len_id),
             title=artifact.title.ljust(len_title),
             category=artifact.category.ljust(len_categ),
             tags=tags.ljust(len_tags),
             author=author.ljust(len_author),
-            status=status.ljust(len_status))
+            status=status.ljust(len_status),
+            template=template.ljust(len_template))
 
         if color and (view_id % 2 == 0):
             print(ALT_BGROUND + result_line + RESET)
